Mixed-Up Code Exercises
------------------------

.. selectquestion:: Classes_Basic_Airport_sq
   :fromid: Classes_Basic_Airport_pp, Classes_Basic_Airport_ac
   :toggle:

.. selectquestion:: Classes_Basic_Song_sq
   :fromid: Classes_Basic_Song_pp, Classes_Basic_Song_ac
   :toggle:

.. selectquestion:: Classes_Basic_Cat_sq
   :fromid: Classes_Basic_Cat_pp, Classes_Basic_Cat_ac
   :toggle:

.. selectquestion:: Classes_Basic_Account_sq
   :fromid: Classes_Basic_Account_pp, Classes_Basic_Account_ac
   :toggle:

.. selectquestion:: Classes_Basic_FortuneTeller_sq
   :fromid: Classes_Basic_FortuneTeller_pp, Classes_Basic_FortuneTeller_ac
   :toggle:

.. selectquestion:: Classes_Basic_Student_sq
   :fromid: Classes_Basic_Student_pp, Classes_Basic_Student_ac
   :toggle:

.. selectquestion:: Classes_Basic_Encoder_sq
   :fromid: Classes_Encoder_Song_pp, Classes_Basic_Encoder_ac
   :toggle:

.. selectquestion:: Classes_Basic_CharFrequency_sq
   :fromid: Classes_Basic_CharFrequency_pp, Classes_Basic_CharFrequency_ac
   :toggle:

.. selectquestion:: Classes_Basic_Loan_sq
   :fromid: Classes_Basic_Loan_pp, Classes_Basic_Loan_ac
   :toggle:

.. selectquestion:: Classes_Basic_Cart_sq
   :fromid: Classes_Basic_Cart1_pp, Classes_Basic_Cart1_ac
   :toggle:
